GreenLight - A model for greenhouses with supplemental lighting
=========================================

A model for simulating the indoor climate and energy use of greenhouses with supplemental lighting. 

## Maintainers
* David Katzin, `david.katzin@wur.nl`, `david.katzin1@gmail.com`

## Cite as

David Katzin, Simon van Mourik, Frank Kempkes, and Eldert J. Van Henten. 2020. “GreenLight - An Open Source Model for Greenhouses with Supplemental Lighting: Evaluation of Heat Requirements under LED and HPS Lamps.” Biosystems Engineering 194: 61–81. https://doi.org/10.1016/j.biosystemseng.2020.03.010.

## Compatability
The code in this repository has been tested for compatibility with MATLAB 2015b and onwards. The [DyMoMa](https://github.com/davkat1/DyMoMa/) package is required in order to use this model. The current version uses [DyMoMa v1.0.1](https://github.com/davkat1/DyMoMa/releases/tag/v1.0.1).

## In this repository

- `readme.md` - This readme file
- `license.md` - The license for this repository (Apache 2.0)
- *Code*
	- `createGreenLightModel` - Files for creating an object of a greenhouse model with lights
	   - `createCropModel.m` - Create only the crop model component of a GreenLight model. See also `exampleCropModel` in `runScenarios`
	   - `createGreenLightModel.m` - Main function for creating a new GreenLight model object. See also `runGreenLight` in `runScenarios`
	   - `setBleiswijk2010HpsParams` - Set the lamp parameters according to the HPS compartment in Bleiswijk, The Netherlands, 2010. Used in [Katzin et al (2020)](https://doi.org/10.1016/j.biosystemseng.2020.03.010)
	   - `setBleiswijk2010LedParams` - Set the lamp parameters according to the LED compartment in Bleiswijk, The Netherlands, 2010. Used in [Katzin et al (2020)](https://doi.org/10.1016/j.biosystemseng.2020.03.010)
	   - `setDefaultLampParams.m` - Set lamp parameters according to modern specifications
	   - `setDepParams.m` - After the parameters have been set, reset the dependent parameters
	   - `setGlAux.m` - Set the auxiliary states 
	   - `setGlControlRules.m` - Set the control rules 
	   - `setGlControls.m` - Set the controls 
	   - `setGlInit.m` - Set the inital values for the states
	   - `setGlInput.m` - Set the inputs
	   - `setGlOdes.m` - Set the ODEs
	   - `setGlParams.m` - Set the parameters according to the Vanthoor model
	   - `setGlStates.m` - Set the states
	   - `setGlTime.m` - Set the timespan
	   - `setParams4haWorldComparison.m` - Set the parameters according to a modern 4 ha greenhouse
	   - `setParamsBleiswijk2010.m` - Set the parameters according to a data set from Bleiswijk, The Netherlands, 2010. Used in [Katzin et al (2020)](https://doi.org/10.1016/j.biosystemseng.2020.03.010)
	- *inputs* - Files for defining the outdoor climate inputs
	   - `cloudCoverRotterdam2009-2012` - Cloud cover data in Rotterdam for the years 2009-2012
	   - `Reference year SEL2000` - Weather data from a Reference Year for Dutch Greenhouses
	   - `energyPlus` - Data from the EnergyPlus database
			- `data` - The actual data files
			- `cutEnergyPlusData.m` - Cut data from EnergyPlus to fit a desired season length
			- `energyPlusCsv2Mat.m` - Convert EnergyPlus data from CSV to MAT
			- `plotYearlyCycleTempRad.m` - Make a plot of yearly cycle of temperature and radiation for all data files
			- `scatterYearAvgTempRad.m` - Make a scatter plot of yearly average temperature and radiation for all data files
			- `readme.txt` - More information on the EnergyPlus data
	   - `dayLightSum.m` - Add a column of daily radiation sum to the input file
	   - `loadGreenhouseData.m` - Load data from Bleiswijk 2010 datasets (tha data not included in this repository)
	   - `loadSelYearHiRes.m` - Load weather data from Reference Year for Dutch Greenhouses
	   - `skyTempMonteith.m` - Calculate sky temperature according to a given air temperature and cloud cover
	   - `skyTempRdam.m` - Calculate sky temperature in Rotterdam according to `skyTempMonteith` and the data in `cloudCoverRotterdam2009-2012`
	   - `soilTempNl.m` - Calculate soil temperature for Dutch conditions
	- *postSimAnalysis* - Methods for analyzing and viewing the simulation after it's done
		- `barEnergyFluxes.m` - Create a bar chart of the energy fluxes
		- `barEnergyFluxesYearWithHeatAdj.m` - Create a bar chart of the energy fluxes, including a simulation with LED heat adjustment
		- `barEnergyUseWorldWide.m` - Create a bar chart of energy use of simulations around the world
		- `energyAnalysis.m` - Calculate the values of the simultaed energy balance
		- `energyCompare.m` - Compare the energy fluxes of two simulations
		- `groPipeEnergy.m` - Calculates how much energy came from the grow pipes
		- `lampOutput.m` - Prints out how the lamp output was broken down between PAR, NIR, FIR, convection, and cooling
		- `pipeEnergy.m` - Calculates how much energy came from the pipe rails	   
		- `pipeT2EnergyIn.m` - Calculates how much energy came from the pipe, based on pipe temperature and the table by Verveer
		- `plotDailyEnergyFullYear.m` - Plot the trajectory of daily energy use throughout the year
		- `plotTemps.m` - Plot the temperatures of the various states in the model
		- `plotWinterSummerDayTrajectory.m` - Plot the trajectories of a chosen day in winter and summer
		- `scatterFracLightSavingsAnalysis.m` - Analyze the energy saving by transition to LEDs, as a function of fraction of energy input that goes to lighting		
		- `verveer.mat` - Table relating pipe temperature and diameter to energy use
		- `verveerReadme.txt` - Explanation regarding the table in `vermeer.mat`
	- *runScenarios* - Scenarios considered in the current study
		- `evaluateClimateModelHps.m` - File used for comparing indoor model simulations with measured data under HPS (data not included in this repo)
		- `evaluateClimateModelLed.m` - File used for comparing indoor model simulations with measured data under LED (data not included in this repo)
		- `evaluateEnergyUseHps.m` - File used for comparing model simulations of energy use with measured data under HPS (data not included in this repo)
		- `evaluateEnergyUseLed.m` - File used for comparing model simulations of energy use with measured data under LED (data not included in this repo)
		- `exampleCropModel.m` - Example of using only the crop model component of GreenLight
		- `exampleSimulation.m` - Example of a simulation with different lamp settings, with data from Reference Year for Dutch Greenhouses
		- `exampleSimulation2.m` - Example of a simulation of a modern greenhouse
		- `runGreenLight.m` - Run the GreenLight model for a modern greenhouse
		- `runWorldSimulations.m` - Run the model in various settings and climates
	- *serviceFunctions* - General use functions 
		- `co2dens2ppm.m` - Convert from CO2 density to ppm
		- `co2ppm2dens.m` - Convert from CO2 in ppm to density
		- `rh2vaporDens.m` - Convert from relative humidity to vapor density
		- `unplot.m` - Remove the last plotted line
		- `vaporDens2pres.m` - Convert from vapor density to vapor pressure
		- `vp2Dens.m` - Convert from vapor pressure to vapor density
		- `vp2dewPt.m` - Convert from vapor pressure to dew point
		
## Using the model

Make sure you have all files in this repository, as well as those from the DyMoMa package, on your MATLAB path. 

`runScenarios\exampleSimulation` shows how you may use a dataset of weather data (in this case, the Reference Year for Dutch Greenhouses), to run the model with default settings. The plot made here is of the lamp temperatures, but you may plot whatver model component you wish.

`runScenarios\exampleSimulation2` shows more uses of the model, now run with settings for a modern greenhouse, including plotting the outputs.

`runScenarios\exampleCropModel.m` gives a simple example of running only the crop component of the model.

Some of the scenarios in `runScenarios` cannot be run without the data from the Bleiswijk 2010 trial, which is not included in this repository. However these examples can be used to run the model with other datasets. You can see in these examples how to compare the model simulations to the measured values, including measured climate variables and energy use.